==> allure-0.11.0.0-104.1-riscv64.pkg.tar.zst: usr/share/haskell/register/allure.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 Allure
version:              0.11.0.0
visibility:           public
id:                   Allure-0.11.0.0-Fgt78tCoALmIm7Zs9VwoXA
key:                  Allure-0.11.0.0-Fgt78tCoALmIm7Zs9VwoXA
license:              AGPL-3.0-or-later
maintainer:           Mikolaj Konarski <mikolaj.konarski@funktory.com>
author:               Andres Loeh, Mikolaj Konarski and others
homepage:             http://allureofthestars.com
synopsis:             Near-future Sci-Fi roguelike and tactical squad combat game
description:
    Allure of the Stars is a near-future Sci-Fi roguelike
    and tactical squad combat game. Binaries and the game manual
    are available at the homepage. You can also try the game out
    in the browser at <http://allureofthestars.com/play>.

    Not a single image in this game. You have to imagine everything
    yourself, like with a book (a grown-up book, without pictures).
    Once you learn to imagine things, though, you can keep exploring
    and mastering the world and making up stories for a long time.

    The game is written in Haskell using the LambdaHack roguelike
    game engine <http://hackage.haskell.org/package/LambdaHack>.
    Please see the changelog file for recent improvements
    and the issue tracker for short-term plans. Long term goals
    are high replayability and auto-balancing through procedural
    content generation and persistent content modification
    based on player behaviour. Contributions are welcome.

    This is a workaround .cabal file, flattened to eliminate
    internal libraries until generating haddocks for them
    is fixed. The original .cabal file is in .cabal.bkp file.

category:             Game
abi:                  6d6b6aeef27cbd336daa2194ffecfb18
exposed:              True
exposed-modules:
    Client.UI.Content.Input Client.UI.Content.Screen Content.CaveKind
    Content.FactionKind Content.ItemKind Content.ItemKindActor
    Content.ItemKindBlast Content.ItemKindEmbed Content.ItemKindOrgan
    Content.ItemKindTemporary Content.ModeKind Content.PlaceKind
    Content.RuleKind Content.TileKind
    Implementation.MonadClientImplementation
    Implementation.MonadServerImplementation TieKnot

hidden-modules:       Paths_Allure
import-dirs:          /usr/lib/ghc-9.0.2/site-local/Allure-0.11.0.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/Allure-0.11.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/allure
hs-libraries:         HSAllure-0.11.0.0-Fgt78tCoALmIm7Zs9VwoXA
depends:
    LambdaHack-0.11.0.0-AJMroxE1tMT8Yf1xnH1KYs
    async-2.2.4-FOEHr9GXtoY2XPADZdvzTY base-4.15.1.0
    enummapset-0.7.1.0-70dGn2BtG1tE57tVhR9yXm
    file-embed-0.0.15.0-FF5xUPWKaB3GI64c6hgPnn filepath-1.4.2.1
    ghc-compact-0.1.0.0 hsini-0.5.1.3-1brEwUGElOkK3oTfJPoZVj
    optparse-applicative-0.17.0.0-1t7fxkFVvXn4R1Ycov0fb
    primitive-0.7.4.0-C645pA0h7V7IRQx9nRPHHH
    splitmix-0.1.0.4-4XnFtgWsHF3JBheb6cs8vv template-haskell-2.17.0.0
    text-1.2.5.0 th-lift-instances-0.1.20-11DuAQiy3Z17qOxLp0HyAg
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/allure/html/Allure.haddock
haddock-html:         /usr/share/doc/allure/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> allure-0.11.0.0-154-riscv64.pkg.tar.zst: usr/share/haskell/register/allure.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 Allure
version:              0.11.0.0
visibility:           public
id:                   Allure-0.11.0.0-KgrBXx7O3lQGJyZzpJqYgT
key:                  Allure-0.11.0.0-KgrBXx7O3lQGJyZzpJqYgT
license:              AGPL-3.0-or-later
maintainer:           Mikolaj Konarski <mikolaj.konarski@funktory.com>
author:               Andres Loeh, Mikolaj Konarski and others
homepage:             http://allureofthestars.com
synopsis:             Near-future Sci-Fi roguelike and tactical squad combat game
description:
    Allure of the Stars is a near-future Sci-Fi roguelike
    and tactical squad combat game. Binaries and the game manual
    are available at the homepage. You can also try the game out
    in the browser at <http://allureofthestars.com/play>.

    Not a single image in this game. You have to imagine everything
    yourself, like with a book (a grown-up book, without pictures).
    Once you learn to imagine things, though, you can keep exploring
    and mastering the world and making up stories for a long time.

    The game is written in Haskell using the LambdaHack roguelike
    game engine <http://hackage.haskell.org/package/LambdaHack>.
    Please see the changelog file for recent improvements
    and the issue tracker for short-term plans. Long term goals
    are high replayability and auto-balancing through procedural
    content generation and persistent content modification
    based on player behaviour. Contributions are welcome.

    This is a workaround .cabal file, flattened to eliminate
    internal libraries until generating haddocks for them
    is fixed. The original .cabal file is in .cabal.bkp file.

category:             Game
abi:                  14593af818249527e3b5e4395df1a16a
exposed:              True
exposed-modules:
    Client.UI.Content.Input Client.UI.Content.Screen Content.CaveKind
    Content.FactionKind Content.ItemKind Content.ItemKindActor
    Content.ItemKindBlast Content.ItemKindEmbed Content.ItemKindOrgan
    Content.ItemKindTemporary Content.ModeKind Content.PlaceKind
    Content.RuleKind Content.TileKind
    Implementation.MonadClientImplementation
    Implementation.MonadServerImplementation TieKnot

hidden-modules:       Paths_Allure
import-dirs:          /usr/lib/ghc-9.2.8/site-local/Allure-0.11.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/Allure-0.11.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/allure
hs-libraries:         HSAllure-0.11.0.0-KgrBXx7O3lQGJyZzpJqYgT
depends:
    LambdaHack-0.11.0.1-CGyX489izyfBFPYPSkH9Gk
    async-2.2.5-Hxx4nU8aNwh7V1GfZTZX85 base-4.16.4.0
    enummapset-0.7.3.0-KOynWyrYarA99O7Fo0sWdP
    file-embed-0.0.15.0-4hNEx1vJ7JTC58fR03LKND filepath-1.4.2.2
    ghc-compact-0.1.0.0 hsini-0.5.2.2-668SBCXU9In9VtCUoee3jg
    optparse-applicative-0.17.1.0-AgMeQrX7nmlDOnX2xcegDb
    primitive-0.7.4.0-AQ7cOoBXu5aBgAQTQzTLUx
    splitmix-0.1.0.5-HVESxjxwSfmC4HE369voNE template-haskell-2.18.0.0
    text-1.2.5.0 th-lift-instances-0.1.20-7UUlrTsIDWL3XQkjxcQngm
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/allure/html/Allure.haddock
haddock-html:         /usr/share/doc/allure/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
